savepinner.pinterest-url-normalizer

Parse and normalize supported Pinterest URL forms without network access.

Parse and normalize supported Pinterest URL forms without network access.
raw docstring

normalize-pinterest-urlclj

(normalize-pinterest-url value)

Return the canonical representation of a supported Pinterest URL.

Return the canonical representation of a supported Pinterest URL.
sourceraw docstring

parse-pinterest-urlclj

(parse-pinterest-url value)

Parse a supported Pinterest URL and return its normalized fields.

Throws ExceptionInfo with :code :invalid-url or :unsupported-url when the input is not supported.

Parse a supported Pinterest URL and return its normalized fields.

Throws ExceptionInfo with :code :invalid-url or :unsupported-url when the
input is not supported.
sourceraw docstring

pinterest-host?clj

(pinterest-host? host)

Return true when host is in the exact Pinterest host allow list.

Return true when host is in the exact Pinterest host allow list.
sourceraw docstring

pinterest-url?clj

(pinterest-url? value)

Return true when value is a supported Pinterest URL.

Return true when value is a supported Pinterest URL.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries