Parse and normalize supported Pinterest URL forms without network access.
Parse and normalize supported Pinterest URL forms without network access.
(normalize-pinterest-url value)Return the canonical representation of a supported Pinterest URL.
Return the canonical representation of a supported Pinterest URL.
(parse-pinterest-url value)Parse a supported Pinterest URL and return its normalized fields.
Throws ExceptionInfo with :code :invalid-url or :unsupported-url when the input is not supported.
Parse a supported Pinterest URL and return its normalized fields. Throws ExceptionInfo with :code :invalid-url or :unsupported-url when the input is not supported.
(pinterest-host? host)Return true when host is in the exact Pinterest host allow list.
Return true when host is in the exact Pinterest host allow list.
(pinterest-url? value)Return true when value is a supported Pinterest URL.
Return true when value is a supported Pinterest URL.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |